searchData={"items":[{"type":"module","title":"AxiomAi","doc":"AxiomAI - A unified Elixir client for multiple AI providers.\n\nThis library provides a consistent interface for interacting with various AI providers\nincluding Vertex AI, OpenAI, Anthropic, and local PyTorch models.","ref":"AxiomAi.html"},{"type":"module","title":"Example - AxiomAi","doc":"iex> client = AxiomAi.new(:vertex_ai, %{project_id: \"my-project\", region: \"us-central1\"})\n    iex> AxiomAi.chat(client, \"Hello, how are you?\")\n    {:ok, %{response: \"I'm doing well, thank you for asking!\"}}","ref":"AxiomAi.html#module-example"},{"type":"function","title":"AxiomAi.chat/2","doc":"Sends a chat message to the AI provider.","ref":"AxiomAi.html#chat/2"},{"type":"function","title":"Parameters - AxiomAi.chat/2","doc":"- client: The client instance\n  - message: The message to send","ref":"AxiomAi.html#chat/2-parameters"},{"type":"function","title":"Examples - AxiomAi.chat/2","doc":"iex> client = AxiomAi.new(:vertex_ai, %{project_id: \"my-project\"})\n    iex> AxiomAi.chat(client, \"What is the weather like?\")\n    {:ok, %{response: \"I don't have access to real-time weather data...\"}}","ref":"AxiomAi.html#chat/2-examples"},{"type":"function","title":"AxiomAi.chat/4","doc":"Sends a chat message with system prompt, history, and user prompt.","ref":"AxiomAi.html#chat/4"},{"type":"function","title":"Parameters - AxiomAi.chat/4","doc":"- client: The client instance\n  - system_prompt: The system prompt to set context\n  - history: List of previous messages in the conversation\n  - prompt: The current user message","ref":"AxiomAi.html#chat/4-parameters"},{"type":"function","title":"Examples - AxiomAi.chat/4","doc":"iex> client = AxiomAi.new(:vertex_ai, %{project_id: \"my-project\"})\n    iex> AxiomAi.chat(client, \"You are a helpful assistant\", [], \"Hello!\")\n    {:ok, %{response: \"Hello! How can I help you today?\"}}","ref":"AxiomAi.html#chat/4-examples"},{"type":"type","title":"AxiomAi.client/0","doc":"","ref":"AxiomAi.html#t:client/0"},{"type":"function","title":"AxiomAi.complete/3","doc":"Generates completions based on a prompt.","ref":"AxiomAi.html#complete/3"},{"type":"function","title":"Parameters - AxiomAi.complete/3","doc":"- client: The client instance\n  - prompt: The prompt to complete\n  - options: Additional options (optional)","ref":"AxiomAi.html#complete/3-parameters"},{"type":"function","title":"Examples - AxiomAi.complete/3","doc":"iex> client = AxiomAi.new(:vertex_ai, %{project_id: \"my-project\"})\n    iex> AxiomAi.complete(client, \"The sky is\", %{max_tokens: 10})\n    {:ok, %{completion: \"blue and clear today.\"}}","ref":"AxiomAi.html#complete/3-examples"},{"type":"type","title":"AxiomAi.config/0","doc":"","ref":"AxiomAi.html#t:config/0"},{"type":"type","title":"AxiomAi.message/0","doc":"","ref":"AxiomAi.html#t:message/0"},{"type":"function","title":"AxiomAi.new/2","doc":"Creates a new client for the specified AI provider.","ref":"AxiomAi.html#new/2"},{"type":"function","title":"Parameters - AxiomAi.new/2","doc":"- provider: The AI provider to use (:vertex_ai, :openai, :anthropic, :local)\n  - config: Provider-specific configuration map","ref":"AxiomAi.html#new/2-parameters"},{"type":"function","title":"Examples - AxiomAi.new/2","doc":"iex> AxiomAi.new(:vertex_ai, %{project_id: \"my-project\", region: \"us-central1\"})\n    %AxiomAi.Client{provider: :vertex_ai, config: %{...}}","ref":"AxiomAi.html#new/2-examples"},{"type":"type","title":"AxiomAi.provider/0","doc":"","ref":"AxiomAi.html#t:provider/0"},{"type":"type","title":"AxiomAi.response/0","doc":"","ref":"AxiomAi.html#t:response/0"},{"type":"module","title":"AxiomAi.Auth","doc":"Authentication utilities for various AI providers.","ref":"AxiomAi.Auth.html"},{"type":"function","title":"AxiomAi.Auth.get_gcp_token/1","doc":"Gets an access token for Google Cloud Platform authentication.\n\nSupports multiple authentication methods:\n- Direct access token (explicit token provided)\n- Service account key data (JSON map)\n- Service account key file (path to JSON file)\n- Application Default Credentials (ADC):\n  * Cloud Run/GCE metadata service (production)\n  * gcloud CLI (local development)","ref":"AxiomAi.Auth.html#get_gcp_token/1"},{"type":"module","title":"AxiomAi.BedrockAuth","doc":"AWS Bedrock authentication and request signing utilities.","ref":"AxiomAi.BedrockAuth.html"},{"type":"function","title":"AxiomAi.BedrockAuth.create_invoke_model_request/4","doc":"Creates an AWS request for Bedrock Runtime InvokeModel API.","ref":"AxiomAi.BedrockAuth.html#create_invoke_model_request/4"},{"type":"function","title":"AxiomAi.BedrockAuth.format_model_payload/3","doc":"Formats model-specific payload for different Bedrock models.","ref":"AxiomAi.BedrockAuth.html#format_model_payload/3"},{"type":"function","title":"AxiomAi.BedrockAuth.get_aws_config/1","doc":"Gets AWS credentials from configuration or environment.\n\nSupports multiple authentication methods:\n- Direct access_key and secret_key in config\n- AWS environment variables (AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY)\n- AWS profiles (~/.aws/credentials)\n- IAM roles (for EC2/ECS/Lambda)","ref":"AxiomAi.BedrockAuth.html#get_aws_config/1"},{"type":"function","title":"AxiomAi.BedrockAuth.parse_model_response/2","doc":"Parses model-specific response from different Bedrock models.","ref":"AxiomAi.BedrockAuth.html#parse_model_response/2"},{"type":"module","title":"AxiomAi.Client","doc":"Client struct and core functionality for AxiomAI.","ref":"AxiomAi.Client.html"},{"type":"function","title":"AxiomAi.Client.chat/2","doc":"Sends a chat message using the configured provider.","ref":"AxiomAi.Client.html#chat/2"},{"type":"function","title":"AxiomAi.Client.chat/4","doc":"Sends a chat message with system prompt, history, and user prompt using the configured provider.","ref":"AxiomAi.Client.html#chat/4"},{"type":"function","title":"AxiomAi.Client.complete/3","doc":"Generates a completion using the configured provider.","ref":"AxiomAi.Client.html#complete/3"},{"type":"type","title":"AxiomAi.Client.t/0","doc":"","ref":"AxiomAi.Client.html#t:t/0"},{"type":"module","title":"AxiomAi.Config","doc":"Configuration validation and management for different AI providers.","ref":"AxiomAi.Config.html"},{"type":"function","title":"AxiomAi.Config.validate/2","doc":"Validates provider-specific configuration.","ref":"AxiomAi.Config.html#validate/2"},{"type":"module","title":"AxiomAi.Http","doc":"HTTP client utilities for AxiomAI.","ref":"AxiomAi.Http.html"},{"type":"function","title":"AxiomAi.Http.get/2","doc":"Performs a GET request.","ref":"AxiomAi.Http.html#get/2"},{"type":"function","title":"AxiomAi.Http.post/3","doc":"Performs a POST request with JSON payload.","ref":"AxiomAi.Http.html#post/3"},{"type":"module","title":"AxiomAi.LocalModels","doc":"Modular configuration system for local AI models.\nSupports multiple model categories with extensible templates and configurations.","ref":"AxiomAi.LocalModels.html"},{"type":"function","title":"AxiomAi.LocalModels.create_custom_config/2","doc":"Creates a custom model configuration using a template.","ref":"AxiomAi.LocalModels.html#create_custom_config/2"},{"type":"function","title":"AxiomAi.LocalModels.get_model_config/1","doc":"Gets a specific model configuration by key.","ref":"AxiomAi.LocalModels.html#get_model_config/1"},{"type":"function","title":"AxiomAi.LocalModels.get_predefined_models/0","doc":"Returns all available model configurations organized by category.","ref":"AxiomAi.LocalModels.html#get_predefined_models/0"},{"type":"function","title":"AxiomAi.LocalModels.list_categories/0","doc":"Gets all available categories.","ref":"AxiomAi.LocalModels.html#list_categories/0"},{"type":"function","title":"AxiomAi.LocalModels.list_models/0","doc":"Lists all available predefined model keys.","ref":"AxiomAi.LocalModels.html#list_models/0"},{"type":"function","title":"AxiomAi.LocalModels.list_models_by_category/1","doc":"Lists models by category.","ref":"AxiomAi.LocalModels.html#list_models_by_category/1"},{"type":"function","title":"AxiomAi.LocalModels.register_model/3","doc":"Registers a new model configuration.","ref":"AxiomAi.LocalModels.html#register_model/3"},{"type":"module","title":"AxiomAi.LocalModels.Categories","doc":"Defines model categories for organizing different types of AI models.","ref":"AxiomAi.LocalModels.Categories.html"},{"type":"function","title":"AxiomAi.LocalModels.Categories.get_description/1","doc":"Gets the description for a category.","ref":"AxiomAi.LocalModels.Categories.html#get_description/1"},{"type":"function","title":"AxiomAi.LocalModels.Categories.list_all/0","doc":"Returns all available model categories.","ref":"AxiomAi.LocalModels.Categories.html#list_all/0"},{"type":"function","title":"AxiomAi.LocalModels.Categories.valid_category?/1","doc":"Validates if a category exists.","ref":"AxiomAi.LocalModels.Categories.html#valid_category?/1"},{"type":"module","title":"AxiomAi.LocalModels.Registry","doc":"Central registry for managing model configurations organized by categories.","ref":"AxiomAi.LocalModels.Registry.html"},{"type":"function","title":"AxiomAi.LocalModels.Registry.add_model/3","doc":"Adds a new model configuration at runtime.","ref":"AxiomAi.LocalModels.Registry.html#add_model/3"},{"type":"function","title":"AxiomAi.LocalModels.Registry.get_all_models/0","doc":"Gets all model configurations.","ref":"AxiomAi.LocalModels.Registry.html#get_all_models/0"},{"type":"function","title":"AxiomAi.LocalModels.Registry.get_model/1","doc":"Gets a specific model configuration by key.","ref":"AxiomAi.LocalModels.Registry.html#get_model/1"},{"type":"function","title":"AxiomAi.LocalModels.Registry.list_all_models/0","doc":"Lists all available model keys.","ref":"AxiomAi.LocalModels.Registry.html#list_all_models/0"},{"type":"function","title":"AxiomAi.LocalModels.Registry.list_models_by_category/1","doc":"Lists models by category.","ref":"AxiomAi.LocalModels.Registry.html#list_models_by_category/1"},{"type":"function","title":"AxiomAi.LocalModels.Registry.remove_model/1","doc":"Removes a runtime model configuration.","ref":"AxiomAi.LocalModels.Registry.html#remove_model/1"},{"type":"module","title":"AxiomAi.LocalModels.Templates","doc":"Template system for creating model configurations with common patterns.","ref":"AxiomAi.LocalModels.Templates.html"},{"type":"function","title":"AxiomAi.LocalModels.Templates.create_from_template/2","doc":"Creates a model configuration from a template.","ref":"AxiomAi.LocalModels.Templates.html#create_from_template/2"},{"type":"function","title":"AxiomAi.LocalModels.Templates.list_templates/0","doc":"Gets available template types.","ref":"AxiomAi.LocalModels.Templates.html#list_templates/0"},{"type":"behaviour","title":"AxiomAi.Provider","doc":"Provider behavior and dispatcher for different AI providers.","ref":"AxiomAi.Provider.html"},{"type":"callback","title":"AxiomAi.Provider.chat/2","doc":"","ref":"AxiomAi.Provider.html#c:chat/2"},{"type":"function","title":"AxiomAi.Provider.chat/3","doc":"Dispatches chat requests to the appropriate provider.","ref":"AxiomAi.Provider.html#chat/3"},{"type":"callback","title":"AxiomAi.Provider.chat/4","doc":"","ref":"AxiomAi.Provider.html#c:chat/4"},{"type":"function","title":"AxiomAi.Provider.chat/5","doc":"Dispatches chat requests with system prompt, history, and user prompt to the appropriate provider.","ref":"AxiomAi.Provider.html#chat/5"},{"type":"callback","title":"AxiomAi.Provider.complete/3","doc":"","ref":"AxiomAi.Provider.html#c:complete/3"},{"type":"function","title":"AxiomAi.Provider.complete/4","doc":"Dispatches completion requests to the appropriate provider.","ref":"AxiomAi.Provider.html#complete/4"},{"type":"module","title":"AxiomAi.Provider.Anthropic","doc":"Anthropic Claude provider implementation.","ref":"AxiomAi.Provider.Anthropic.html"},{"type":"module","title":"AxiomAi.Provider.Bedrock","doc":"AWS Bedrock provider implementation.\n\nSupports multiple model families:\n- Anthropic Claude (anthropic.claude-*)\n- Amazon Titan (amazon.titan-*)\n- Meta Llama (meta.llama*)\n- AI21 Jurassic (ai21.j2-*)","ref":"AxiomAi.Provider.Bedrock.html"},{"type":"module","title":"AxiomAi.Provider.DeepSeek","doc":"DeepSeek AI provider implementation.","ref":"AxiomAi.Provider.DeepSeek.html"},{"type":"module","title":"AxiomAi.Provider.Local","doc":"Local AI provider implementation for self-hosted models.\n\nSupports both HTTP endpoints (OpenAI-compatible APIs, Ollama, etc.)\nand direct Python script execution for local models.","ref":"AxiomAi.Provider.Local.html"},{"type":"module","title":"AxiomAi.Provider.OpenAi","doc":"OpenAI provider implementation.","ref":"AxiomAi.Provider.OpenAi.html"},{"type":"module","title":"AxiomAi.Provider.VertexAi","doc":"Google Vertex AI provider implementation.","ref":"AxiomAi.Provider.VertexAi.html"},{"type":"extras","title":"AxiomAI","doc":"# AxiomAI\n\n[![Hex.pm](https://img.shields.io/hexpm/v/axiom_ai.svg)](https://hex.pm/packages/axiom_ai)\n[![Documentation](https://img.shields.io/badge/docs-hexdocs-blue.svg)](https://hexdocs.pm/axiom_ai/)\n\nA unified Elixir client for multiple AI providers.","ref":"readme.html"},{"type":"extras","title":"Installation - AxiomAI","doc":"```elixir\ndef deps do\n  [\n    {:axiom_ai, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - AxiomAI","doc":"```elixir\n# Vertex AI (Google Cloud)\nclient = AxiomAi.new(:vertex_ai, %{project_id: \"your-gcp-project\"})\n{:ok, response} = AxiomAi.chat(client, \"Hello!\")\n\n# OpenAI\nclient = AxiomAi.new(:openai, %{api_key: \"your-openai-key\"})\n{:ok, response} = AxiomAi.chat(client, \"Hello!\")\n\n# Anthropic Claude\nclient = AxiomAi.new(:anthropic, %{api_key: \"your-anthropic-key\"})\n{:ok, response} = AxiomAi.chat(client, \"Hello!\")\n\n# Local AI models\nclient = AxiomAi.new(:local, %{predefined_model: \"qwen2.5-0.5b\"})\n{:ok, response} = AxiomAi.chat(client, \"Hello!\")\n\n# Whisper speech-to-text\nclient = AxiomAi.new(:local, %{predefined_model: \"whisper-large-v3-turbo\"})\n{:ok, response} = AxiomAi.chat(client, \"/path/to/audio.wav|Transcribe this audio\")\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"Supported Providers - AxiomAI","doc":"| Provider | Authentication | Example |\n|----------|---------------|---------|\n| **Vertex AI** | Service Account, ADC | `AxiomAi.new(:vertex_ai, %{project_id: \"my-project\"})` |\n| **OpenAI** | API Key | `AxiomAi.new(:openai, %{api_key: \"sk-...\"})` |\n| **Anthropic** | API Key | `AxiomAi.new(:anthropic, %{api_key: \"sk-...\"})` |\n| **DeepSeek** | API Key | `AxiomAi.new(:deepseek, %{api_key: \"sk-...\"})` |\n| **AWS Bedrock** | AWS Credentials | `AxiomAi.new(:bedrock, %{model: \"anthropic.claude-3-haiku-20240307-v1:0\"})` |\n| **Local AI** | None | `AxiomAi.new(:local, %{predefined_model: \"qwen2.5-0.5b\"})` |","ref":"readme.html#supported-providers"},{"type":"extras","title":"Predefined Local Models - AxiomAI","doc":"```elixir\n# List available models\nmodels = AxiomAi.LocalModels.list_models()\nIO.inspect(models)\n```\n\n**Available Models:**\n\n**Text Generation:**\n- `qwen2.5-0.5b` - Qwen2.5 0.5B\n- `qwen2.5-1.5b` - Qwen2.5 1.5B  \n- `qwen2.5-3b` - Qwen2.5 3B\n- `llama3-8b` - Llama 3 8B\n- `mistral-7b` - Mistral 7B\n- `codellama-7b` - Code Llama 7B\n\n**Speech-to-Text:**\n- `whisper-large-v3` - Whisper Large v3\n- `whisper-large-v3-turbo` - Whisper Large v3 Turbo\n\n**OCR:**\n- `nanonets-ocr-s` - Nanonets OCR Small","ref":"readme.html#predefined-local-models"},{"type":"extras","title":"Authentication - AxiomAI","doc":"","ref":"readme.html#authentication"},{"type":"extras","title":"Vertex AI - AxiomAI","doc":"```bash\n# Local development\ngcloud auth application-default login\n\n# Production\nexport GOOGLE_APPLICATION_CREDENTIALS=\"/path/to/service-account.json\"\n```","ref":"readme.html#vertex-ai"},{"type":"extras","title":"Environment Variables - AxiomAI","doc":"```bash\n# .env file\nGOOGLE_CLOUD_PROJECT=your-project-id\nOPENAI_API_KEY=your-openai-key\nANTHROPIC_API_KEY=your-anthropic-key\nDEEPSEEK_API_KEY=your-deepseek-key\nAWS_ACCESS_KEY_ID=your-aws-key\nAWS_SECRET_ACCESS_KEY=your-aws-secret\n```","ref":"readme.html#environment-variables"},{"type":"extras","title":"Configuration Options - AxiomAI","doc":"```elixir\nclient = AxiomAi.new(:vertex_ai, %{\n  project_id: \"your-project\",\n  model: \"gemini-1.5-pro\",      # optional\n  region: \"us-central1\",        # optional\n  temperature: 0.7,             # optional\n  max_tokens: 1000             # optional\n})\n```","ref":"readme.html#configuration-options"},{"type":"extras","title":"Credentials Configuration - AxiomAI","doc":"","ref":"readme.html#credentials-configuration"},{"type":"extras","title":"Vertex AI Service Account Setup - AxiomAI","doc":"#### Method 1: Service Account File Path\n```elixir\nconfig = %{\n  project_id: \"your-gcp-project\",\n  service_account_path: \"/path/to/service-account.json\",\n  model: \"gemini-1.5-pro\",\n  region: \"us-central1\"\n}\n\nclient = AxiomAi.new(:vertex_ai, config)\n```\n\n#### Method 2: Service Account Key Data\n```elixir\n# Load credentials from file\n{:ok, creds_json} = File.read(\"/path/to/service-account.json\")\n{:ok, creds_map} = Jason.decode(creds_json)\n\nconfig = %{\n  project_id: \"your-gcp-project\",\n  service_account_key: creds_map,\n  model: \"gemini-1.5-pro\",\n  region: \"us-central1\"\n}\n\nclient = AxiomAi.new(:vertex_ai, config)\n```\n\n#### Method 3: Direct Access Token\n```elixir\nconfig = %{\n  project_id: \"your-gcp-project\",\n  access_token: \"ya29.your-access-token\",\n  model: \"gemini-1.5-pro\",\n  region: \"us-central1\"\n}\n\nclient = AxiomAi.new(:vertex_ai, config)\n```\n\n#### Method 4: Application Default Credentials (ADC)\n```elixir\n# Automatically detects environment and uses appropriate method:\n# - Cloud Run/GCE: Uses metadata service\n# - Local: Uses gcloud CLI\nconfig = %{\n  project_id: \"your-gcp-project\",\n  model: \"gemini-1.5-pro\",\n  region: \"us-central1\"\n}\n\nclient = AxiomAi.new(:vertex_ai, config)\n```","ref":"readme.html#vertex-ai-service-account-setup"},{"type":"extras","title":"Cloud Run Deployment - AxiomAI","doc":"**✅ Recommended: Use the default service account**\n```elixir\n# Cloud Run automatically provides credentials via metadata service\nconfig = %{\n  project_id: \"your-gcp-project\",\n  model: \"gemini-1.5-pro\"\n}\n```\n\nThe library automatically detects Cloud Run environment and uses the metadata service for authentication. No additional configuration needed.\n\n**Alternative: Mount service account file**\n```dockerfile\n# In your Dockerfile\nCOPY service-account.json /app/credentials.json\n```\n\n```elixir\n# In your application\nconfig = %{\n  project_id: \"your-gcp-project\",\n  service_account_path: \"/app/credentials.json\",\n  model: \"gemini-1.5-pro\"\n}\n```","ref":"readme.html#cloud-run-deployment"},{"type":"extras","title":"Required IAM Permissions - AxiomAI","doc":"Ensure your service account has the following roles:\n- `roles/aiplatform.user` - For Vertex AI API access\n- `roles/ml.developer` - For ML model operations (optional)\n\n```bash\n# Grant permissions\ngcloud projects add-iam-policy-binding your-gcp-project \\\n  --member=\"serviceAccount:your-service-account@your-gcp-project.iam.gserviceaccount.com\" \\\n  --role=\"roles/aiplatform.user\"\n```","ref":"readme.html#required-iam-permissions"},{"type":"extras","title":"License - AxiomAI","doc":"MIT License","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}